add_distinct_call

Function add_distinct_call 

pub fn add_distinct_call(
    config: &str,
    params: AddDistinctCallParams,
) -> Result<(String, Value)>
Add a new distinct call with element list

Creates a new distinct call linking a function to a feature with associated elements (DBOM records). Note: Only one distinct call is allowed per feature.

Arguments

  • config - Configuration JSON string
  • params - Distinct call parameters (ftype_code, dfunc_code, element_list required)

Returns

Tuple of (modified_config, new_dfcall_record)

Errors

  • Duplicate if a distinct call already exists for this feature
  • NotFound if function/feature/element codes don’t exist