add_expression_call

Function add_expression_call 

pub fn add_expression_call(
    config: &str,
    params: AddExpressionCallParams<'_>,
) -> Result<(String, Value)>
Add a new expression call with element list

Creates a new expression call linking a function to a feature or element with an execution order and associated elements (EBOM records).

Arguments

  • config - Configuration JSON string
  • params - Expression call parameters

Returns

Tuple of (modified_config, new_efcall_record)

Errors

  • InvalidParameter if both ftype_code and felem_code are specified or both missing
  • Duplicate if exec_order is already taken for the feature/element
  • NotFound if function/feature/element codes don’t exist